"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
// controllers/VehicleTypeController.ts
const express_1 = require("express");
const Account_1 = __importDefault(require("../Models/Account"));
class AccountController {
    static async create(req, res) {
        try {
            const { name, number, bank } = req.body;
            const account = await Account_1.default.create(name, number, bank);
            res.status(201).json(account);
        }
        catch (error) {
            console.error(error);
            res.status(500).send("Internal Server Error");
        }
    }
    static async update(req, res) {
        try {
            const id = req.params.id;
            const { name, number, bank } = req.body;
            const account = await Account_1.default.update(id, name, number, bank);
            res.status(201).json(account);
        }
        catch (error) {
            console.error(error);
            res.status(500).send("Internal Server Error");
        }
    }
    static async get(req, res) {
        try {
            const accounts = await Account_1.default.get();
            res.json(accounts);
        }
        catch (error) {
            console.error(error);
            res.status(500).send("Internal Server Error");
        }
    }
    static async delete(req, res) {
        try {
            const id = req.params.id;
            await Account_1.default.delete(id);
            res.status(204).send(); // No content on successful deletion
        }
        catch (error) {
            console.error(error);
            res.status(500).json({ error: "Internal Server Error" });
        }
    }
    static getRouter() {
        const router = (0, express_1.Router)();
        router.post("/", this.create);
        router.put("/:id", this.update);
        router.get("/", this.get);
        router.delete("/:id", this.delete);
        return router;
    }
}
exports.default = AccountController;
