"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
// controllers/UserController.ts
const express_1 = require("express");
const User_1 = __importDefault(require("../Models/User"));
const Cart_1 = __importDefault(require("../Models/Cart"));
const Product_1 = __importDefault(require("../Models/Product"));
const Order_1 = __importDefault(require("../Models/Order"));
const OrderItem_1 = __importDefault(require("../Models/OrderItem"));
const Analytic_1 = __importDefault(require("../Models/Analytic"));
const upload_1 = __importDefault(require("../upload"));
class CartController {
    static async checkout(req, res) {
        try {
            const { items: itemsrow } = req.body;
            const authHeader = req.headers.authorization; // or req.get('authorization')
            const user = await User_1.default.getByToken(authHeader);
            const items = JSON.parse(itemsrow);
            const invoice = req.file?.path;
            if (!invoice) {
                res.status(422).send("No Invoice");
                return;
            }
            const products_ids = items.map((item) => item.id);
            const products = await Product_1.default.getbyidarray(products_ids);
            const result = products.map((product) => {
                const count = items.find((item) => item.id === product.id)?.count;
                try {
                    Analytic_1.default.addparchace(user.id, product.id);
                }
                catch (error) { }
                return product.price * (count || 1);
            });
            const total = result.reduce((prev, current) => prev + current, 0);
            const orderid = await Order_1.default.create(user.id, total, 0, invoice);
            await Promise.all(products.map(async (product) => {
                const count = items.find((item) => item.id === product.id)?.count;
                await OrderItem_1.default.create(orderid, product.id, product.price, count || 1);
            }));
            await Cart_1.default.deleteAll(user.id);
            res.status(201).json({ message: "success" });
        }
        catch (error) {
            console.error(error);
            res.status(500).send("Internal Server Error");
        }
    }
    static async create(req, res) {
        try {
            const { product_id } = req.body;
            const authHeader = req.headers.authorization; // or req.get('authorization')
            const user = await User_1.default.getByToken(authHeader);
            const service = await Cart_1.default.create(user.id, product_id);
            res.status(201).json(service);
        }
        catch (error) {
            console.error(error);
            res.status(500).send("Internal Server Error");
        }
    }
    static async get(req, res) {
        try {
            const authHeader = req.headers.authorization; // or req.get('authorization')
            const user = await User_1.default.getByToken(authHeader);
            const users = await Cart_1.default.get(user.id);
            res.json(users);
        }
        catch (error) {
            console.error(error);
            res.status(500).send("Internal Server Error");
        }
    }
    static async delete(req, res) {
        try {
            const id = req.params.id;
            await Cart_1.default.delete(id);
            res.status(204).send(); // No content on successful deletion
        }
        catch (error) {
            console.error(error);
            res.status(500).json({ error: "Internal Server Error" });
        }
    }
    static async deleteAll(req, res) {
        try {
            const authHeader = req.headers.authorization; // or req.get('authorization')
            const user = await User_1.default.getByToken(authHeader);
            await Cart_1.default.deleteAll(user.id);
            res.status(204).send(); // No content on successful deletion
        }
        catch (error) {
            console.error(error);
            res.status(500).json({ error: "Internal Server Error" });
        }
    }
    static getRouter() {
        const router = (0, express_1.Router)();
        router.post("/checkout", upload_1.default.single("photo"), this.checkout);
        router.post("/", this.create);
        router.get("/", this.get);
        router.delete("/all", this.deleteAll);
        router.delete("/:id", this.delete);
        return router;
    }
}
exports.default = CartController;
