"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
// controllers/UserController.ts
const express_1 = require("express");
const Category_1 = __importDefault(require("../Models/Category"));
const upload_1 = __importDefault(require("../upload"));
class CategoriesAdminController {
    static async create(req, res) {
        try {
            const { name } = req.body;
            const photo = req.file?.path;
            const service = await Category_1.default.create(name, photo || "");
            res.status(201).json(service);
        }
        catch (error) {
            console.error(error);
            // @ts-ignore
            res.status(500).send({ error: error.message });
        }
    }
    static async update(req, res) {
        try {
            const id = req.params.id;
            const { name } = req.body;
            const photo = req.file?.path;
            console.log(photo);
            const user = await Category_1.default.update(id, name, photo);
            res.status(201).json(user);
        }
        catch (error) {
            console.error(error);
            res.status(500).send(error);
        }
    }
    static async getById(req, res) {
        try {
            const id = req.params.id;
            const categories = await Category_1.default.getById(id);
            res.json(categories);
        }
        catch (error) {
            console.error(error);
            res.status(500).send("Internal Server Error");
        }
    }
    static async get(req, res) {
        try {
            const users = await Category_1.default.getCategories();
            res.json(users);
        }
        catch (error) {
            console.error(error);
            res.status(500).send("Internal Server Error");
        }
    }
    static async search(req, res) {
        try {
            const keyword = req.params.keyword;
            const users = await Category_1.default.search(keyword);
            res.json(users);
        }
        catch (error) {
            console.error(error);
            res.status(500).send("Internal Server Error");
        }
    }
    static async delete(req, res) {
        try {
            const id = req.params.id;
            await Category_1.default.delete(id);
            res.status(204).send(); // No content on successful deletion
        }
        catch (error) {
            console.error(error);
            res.status(500).json({ error: "Internal Server Error" });
        }
    }
    static getRouter() {
        const router = (0, express_1.Router)();
        router.post("/", upload_1.default.single("photo"), this.create);
        router.put("/:id", upload_1.default.single("photo"), this.update);
        router.get("/", this.get);
        router.get("/search/:keyword", this.search);
        router.get("/:id", this.getById);
        router.delete("/:id", this.delete);
        return router;
    }
}
exports.default = CategoriesAdminController;
