"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
// controllers/UserController.ts
const express_1 = require("express");
const User_1 = __importDefault(require("../Models/User"));
const Comments_1 = __importDefault(require("../Models/Comments"));
class CommentController {
    static async create(req, res) {
        try {
            const { product_id, text } = req.body;
            const authHeader = req.headers.authorization; // or req.get('authorization')
            const user = await User_1.default.getByToken(authHeader);
            const service = await Comments_1.default.create(user.id, product_id, text);
            res.status(201).json(service);
        }
        catch (error) {
            console.error(error);
            if (error === "username already used")
                res.status(422).send(error);
            else
                res.status(500).send("Internal Server Error");
        }
    }
    static async get(req, res) {
        try {
            const id = req.params.id;
            const page = req.query.page;
            const p = page;
            const users = await Comments_1.default.getAllCommentsByNews(id, parseInt(p || "1"));
            res.json(users);
        }
        catch (error) {
            console.error(error);
            res.status(500).send("Internal Server Error");
        }
    }
    static async delete(req, res) {
        try {
            const id = req.params.id;
            await Comments_1.default.delete(id);
            res.status(204).send(); // No content on successful deletion
        }
        catch (error) {
            console.error(error);
            res.status(500).json({ error: "Internal Server Error" });
        }
    }
    static getRouter() {
        const router = (0, express_1.Router)();
        router.post("/", this.create);
        router.get("/:id", this.get);
        router.delete("/:id", this.delete);
        return router;
    }
}
exports.default = CommentController;
