"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
// controllers/UserController.ts
const express_1 = require("express");
const User_1 = __importDefault(require("../Models/User"));
const DailyUse_1 = __importDefault(require("../Models/DailyUse"));
class DailyUseController {
    static async create(req, res) {
        try {
            const { product_id, day } = req.body;
            const authHeader = req.headers.authorization; // or req.get('authorization')
            const user = await User_1.default.getByToken(authHeader);
            await Promise.all(day.map(async (d) => {
                await DailyUse_1.default.create(user.id, product_id, d);
            }));
            res.status(201).json("success");
        }
        catch (error) {
            console.log(error);
            res.status(500).send("Internal Server Error");
        }
    }
    static async get(req, res) {
        try {
            const date = req.params.date;
            const authHeader = req.headers.authorization; // or req.get('authorization')
            const user = await User_1.default.getByToken(authHeader);
            const DailyUses = await DailyUse_1.default.getByDay(user.id, date);
            res.json(DailyUses);
        }
        catch (error) {
            console.error(error);
            res.status(500).send("Internal Server Error");
        }
    }
    static async record(req, res) {
        try {
            const id = req.params.id;
            await DailyUse_1.default.record(id);
            res.status(204).send(); // No content on successful deletion
        }
        catch (error) {
            console.error(error);
            res.status(500).json({ error: "Internal Server Error" });
        }
    }
    static async delete(req, res) {
        try {
            const id = req.params.id;
            await DailyUse_1.default.delete(id);
            res.status(204).send(); // No content on successful deletion
        }
        catch (error) {
            console.error(error);
            res.status(500).json({ error: "Internal Server Error" });
        }
    }
    static getRouter() {
        const router = (0, express_1.Router)();
        router.post("/", this.create);
        router.get("/:date", this.get);
        router.delete("/:id", this.delete);
        router.put("/:id", this.record);
        return router;
    }
}
exports.default = DailyUseController;
