"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
// controllers/LoginController.ts
const express_1 = require("express");
const Category_1 = __importDefault(require("../Models/Category"));
const Product_1 = __importDefault(require("../Models/Product"));
const User_1 = __importDefault(require("../Models/User"));
const Analytic_1 = __importDefault(require("../Models/Analytic"));
const Topic_1 = __importDefault(require("../Models/Topic"));
const News_1 = __importDefault(require("../Models/News"));
class GetController {
    static async getCategories(req, res) {
        try {
            const data = await Category_1.default.getCategories();
            res.json(data);
        }
        catch (error) {
            console.log(error);
            // @ts-ignore
            res.status(500).json({ error: error });
        }
    }
    static async getHomePersonlizedProducts(req, res) {
        try {
            const id = req.params.id;
            const authHeader = req.headers.authorization; // or req.get('authorization')
            const user = await User_1.default.getByToken(authHeader);
            const data = await Product_1.default.getHomePersonlizedProducts(user.id);
            res.json(data);
        }
        catch (error) {
            console.log(error);
            // @ts-ignore
            res.status(500).json({ error: error });
        }
    }
    static async getProductsById(req, res) {
        try {
            const id = req.params.id;
            const authHeader = req.headers.authorization; // or req.get('authorization')
            const user = await User_1.default.getByToken(authHeader);
            const data = await Product_1.default.getById(id);
            await Analytic_1.default.addProductView(user.id, data.id);
            res.json(data);
        }
        catch (error) {
            console.log(error);
            // @ts-ignore
            res.status(500).json({ error: error });
        }
    }
    static async getProductsBySearch(req, res) {
        try {
            const keyword = req.params.keyword;
            const page = req.query.page;
            const p = page;
            const authHeader = req.headers.authorization; // or req.get('authorization')
            const user = await User_1.default.getByToken(authHeader);
            if (p == "1")
                await Analytic_1.default.addProductsearch(user.id, keyword);
            const products = await Product_1.default.searchproducts(keyword, parseInt(p || "1"));
            res.json(products);
        }
        catch (error) {
            console.log(error);
            // @ts-ignore
            res.status(500).json({ error: error });
        }
    }
    static async getProductsByCategory(req, res) {
        try {
            const id = req.params.id;
            const page = req.query.page;
            const p = page;
            const authHeader = req.headers.authorization; // or req.get('authorization')
            const user = await User_1.default.getByToken(authHeader);
            const data = await Product_1.default.getByCategory(id, parseInt(p || "1"));
            res.json(data);
        }
        catch (error) {
            console.log(error);
            // @ts-ignore
            res.status(500).json({ error: error });
        }
    }
    static async getTopics(req, res) {
        try {
            const data = await Topic_1.default.get();
            res.json(data);
        }
        catch (error) {
            console.log(error);
            // @ts-ignore
            res.status(500).json({ error: error });
        }
    }
    static async getHomePersonlizedNews(req, res) {
        try {
            const id = req.params.id;
            const authHeader = req.headers.authorization; // or req.get('authorization')
            const user = await User_1.default.getByToken(authHeader);
            const data = await News_1.default.getHomePersonalizedNews(user.id);
            res.json(data);
        }
        catch (error) {
            console.log(error);
            // @ts-ignore
            res.status(500).json({ error: error });
        }
    }
    static async getNewsById(req, res) {
        try {
            const id = req.params.id;
            const authHeader = req.headers.authorization; // or req.get('authorization')
            const user = await User_1.default.getByToken(authHeader);
            const data = await News_1.default.getById(id);
            await Analytic_1.default.addnewsView(user.id, data.id);
            res.json(data);
        }
        catch (error) {
            console.log(error);
            // @ts-ignore
            res.status(500).json({ error: error });
        }
    }
    static async getNewsBySearch(req, res) {
        try {
            const keyword = req.params.keyword;
            const page = req.query.page;
            const p = page;
            const authHeader = req.headers.authorization; // or req.get('authorization')
            const user = await User_1.default.getByToken(authHeader);
            if (p == "1")
                await Analytic_1.default.addnewssearch(user.id, keyword);
            const news = await News_1.default.searchNewss(keyword, parseInt(p || "1"));
            res.json(news);
        }
        catch (error) {
            console.log(error);
            // @ts-ignore
            res.status(500).json({ error: error });
        }
    }
    static async getnewsByTopic(req, res) {
        try {
            const id = req.params.id;
            const page = req.query.page;
            const p = page;
            const authHeader = req.headers.authorization; // or req.get('authorization')
            const user = await User_1.default.getByToken(authHeader);
            const data = await News_1.default.Topic(id, parseInt(p || "1"));
            res.json(data);
        }
        catch (error) {
            console.log(error);
            // @ts-ignore
            res.status(500).json({ error: error });
        }
    }
    static getRouter() {
        const router = (0, express_1.Router)();
        router.get("/categories", this.getCategories);
        router.get("/products-by-category/:id", this.getProductsByCategory);
        router.get("/products-by-search/:keyword", this.getProductsBySearch);
        router.get("/products-by-id/:id", this.getProductsById);
        router.get("/home-products", this.getHomePersonlizedProducts);
        router.get("/topics", this.getTopics);
        router.get("/news-by-topic/:id", this.getnewsByTopic);
        router.get("/news-by-search/:keyword", this.getNewsBySearch);
        router.get("/news-by-id/:id", this.getNewsById);
        router.get("/home-news", this.getHomePersonlizedNews);
        return router;
    }
}
exports.default = GetController;
