"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
// controllers/UserController.ts
const express_1 = require("express");
const upload_1 = __importDefault(require("../upload"));
const News_1 = __importDefault(require("../Models/News"));
const Comments_1 = __importDefault(require("../Models/Comments"));
class NewsAdminController {
    static async create(req, res) {
        try {
            const { title, content, topic_id } = req.body;
            const photo = req.file?.path;
            const service = await News_1.default.create(title, content, topic_id, photo);
            res.status(201).json(service);
        }
        catch (error) {
            console.error(error);
            if (error === "username already used")
                res.status(422).send(error);
            else
                res.status(500).send("Internal Server Error");
        }
    }
    static async update(req, res) {
        try {
            const id = req.params.id;
            const { title, content, topic_id } = req.body;
            const photo = req.file?.path;
            const user = await News_1.default.update(id, title, content, topic_id, photo);
            res.status(201).json(user);
        }
        catch (error) {
            console.error(error);
            res.status(500).send(error);
        }
    }
    static async get(req, res) {
        try {
            const page = req.query.page;
            const p = page;
            const users = await News_1.default.getNewss(parseInt(p || "1"));
            res.json(users);
        }
        catch (error) {
            console.error(error);
            res.status(500).send("Internal Server Error");
        }
    }
    static async search(req, res) {
        try {
            const keyword = req.params.keyword;
            const users = await News_1.default.search(keyword);
            res.json(users);
        }
        catch (error) {
            console.error(error);
            res.status(500).send("Internal Server Error");
        }
    }
    static async delete(req, res) {
        try {
            const id = req.params.id;
            await News_1.default.delete(id);
            res.status(204).send(); // No content on successful deletion
        }
        catch (error) {
            console.error(error);
            res.status(500).json({ error: "Internal Server Error" });
        }
    }
    static async deleteComment(req, res) {
        try {
            const id = req.params.id;
            await Comments_1.default.delete(id);
            res.status(204).send(); // No content on successful deletion
        }
        catch (error) {
            console.error(error);
            res.status(500).json({ error: "Internal Server Error" });
        }
    }
    static async getComments(req, res) {
        try {
            const page = req.query.page;
            const id = req.params.id;
            const p = page;
            const users = await Comments_1.default.getAllCommentsByNews(id, parseInt(p || "1"));
            res.json(users);
        }
        catch (error) {
            console.error(error);
            res.status(500).send("Internal Server Error");
        }
    }
    static getRouter() {
        const router = (0, express_1.Router)();
        router.post("/", upload_1.default.single("photo"), this.create);
        router.put("/:id", upload_1.default.single("photo"), this.update);
        router.get("/", this.get);
        router.get("/:id", this.getComments);
        router.get("/:id/search/:keyword", this.search);
        router.delete("/:id", this.delete);
        router.delete("/comment/:id", this.deleteComment);
        return router;
    }
}
exports.default = NewsAdminController;
