"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
// controllers/UserController.ts
const express_1 = require("express");
const upload_1 = __importDefault(require("../upload"));
const Product_1 = __importDefault(require("../Models/Product"));
const Reviews_1 = __importDefault(require("../Models/Reviews"));
class ProductsAdminController {
    static async create(req, res) {
        try {
            const { name, description, usage_describtion, Category_id, price, recomended_usage } = req.body;
            const photo = req.file?.path;
            const service = await Product_1.default.create(name, Category_id, description, usage_describtion, price, recomended_usage, photo);
            res.status(201).json(service);
        }
        catch (error) {
            console.error(error);
            if (error === "username already used")
                res.status(422).send(error);
            else
                res.status(500).send("Internal Server Error");
        }
    }
    static async update(req, res) {
        try {
            const id = req.params.id;
            const { name, description, recomended_usage, Category_id, price, usage_describtion } = req.body;
            const photo = req.file?.path;
            const user = await Product_1.default.update(id, name, Category_id, description, usage_describtion, price, recomended_usage, photo);
            res.status(201).json(user);
        }
        catch (error) {
            console.error(error);
            res.status(500).send(error);
        }
    }
    static async get(req, res) {
        try {
            const page = req.query.page;
            const p = page;
            const users = await Product_1.default.getProducts(parseInt(p || "1"));
            res.json(users);
        }
        catch (error) {
            console.error(error);
            res.status(500).send("Internal Server Error");
        }
    }
    static async getReviews(req, res) {
        try {
            const page = req.query.page;
            const id = req.params.id;
            const p = page;
            const users = await Reviews_1.default.getAllReviewsByProduct(id, parseInt(p || "1"));
            res.json(users);
        }
        catch (error) {
            console.error(error);
            res.status(500).send("Internal Server Error");
        }
    }
    static async search(req, res) {
        try {
            const keyword = req.params.keyword;
            const id = req.params.id;
            const users = await Product_1.default.search(keyword);
            res.json(users);
        }
        catch (error) {
            console.error(error);
            res.status(500).send("Internal Server Error");
        }
    }
    static async delete(req, res) {
        try {
            const id = req.params.id;
            await Product_1.default.delete(id);
            res.status(204).send(); // No content on successful deletion
        }
        catch (error) {
            console.error(error);
            res.status(500).json({ error: "Internal Server Error" });
        }
    }
    static async deleteReview(req, res) {
        try {
            const id = req.params.id;
            await Reviews_1.default.delete(id);
            res.status(204).send(); // No content on successful deletion
        }
        catch (error) {
            console.error(error);
            res.status(500).json({ error: "Internal Server Error" });
        }
    }
    static getRouter() {
        const router = (0, express_1.Router)();
        router.post("/", upload_1.default.single("photo"), this.create);
        router.put("/:id", upload_1.default.single("photo"), this.update);
        router.get("/", this.get);
        router.get("/:id", this.getReviews);
        router.get("/search/:keyword", this.search);
        router.delete("/:id", this.delete);
        router.delete("/review/:id", this.deleteReview);
        return router;
    }
}
exports.default = ProductsAdminController;
