"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
// controllers/LoginController.ts
const express_1 = require("express");
const Page_1 = __importDefault(require("../Models/Page"));
const User_1 = __importDefault(require("../Models/User"));
const Account_1 = __importDefault(require("../Models/Account"));
class PublicController {
    static async getPages(req, res) {
        try {
            const data = await Page_1.default.getAll();
            res.json(data);
        }
        catch (error) {
            console.log(error);
            // @ts-ignore
            res.status(500).json({ error: error });
        }
    }
    static async getPage(req, res) {
        try {
            const name = req.params.name;
            const data = await Page_1.default.getByname(name);
            // Render the HTML response
            res.send(`
      <!DOCTYPE html>
      <html lang="en">
      <head>
        <meta charset="UTF-8">
        <meta name="viewport" content="width=device-width, initial-scale=1.0">
        <title>${name}</title>
        <style>
          body { font-family: Arial, sans-serif; margin: 2em; line-height: 1.6; }
        </style>
      </head>
      <body>
        <h1>${name}</h1>
        <div>${data}</div>
      </body>
      </html>
    `);
        }
        catch (error) {
            console.error(error);
            res.status(500).send(`
      <!DOCTYPE html>
      <html lang="en">
      <head>
        <meta charset="UTF-8">
        <meta name="viewport" content="width=device-width, initial-scale=1.0">
        <title>Error</title>
      </head>
      <body>
        <h1>Something went wrong</h1>
        <p>${error instanceof Error ? error.message : "Unknown error"}</p>
      </body>
      </html>
    `);
        }
    }
    static async deleteAccount(req, res) {
        try {
            const { phone, password } = req.body;
            console.log(phone, password, req.body);
            // Validate and authenticate the user
            const data = await User_1.default.login(phone, password);
            // Delete the user account
            await User_1.default.delete(data.user.id);
            // Render success HTML response
            res.send(`
      <!DOCTYPE html>
      <html lang="en">
      <head>
        <meta charset="UTF-8">
        <meta name="viewport" content="width=device-width, initial-scale=1.0">
        <title>Account Deleted</title>
        <style>
          body {
            font-family: Arial, sans-serif;
            background-color: #f0f8ff;
            margin: 0;
            padding: 0;
            display: flex;
            justify-content: center;
            align-items: center;
            height: 100vh;
          }
          .container {
            text-align: center;
            background-color: #fff;
            padding: 20px;
            border-radius: 10px;
            box-shadow: 0 4px 6px rgba(0, 0, 0, 0.1);
            max-width: 400px;
            width: 100%;
          }
          h1 {
            color: #28a745;
            margin-bottom: 20px;
          }
          p {
            color: #333;
            font-size: 1rem;
          }
        </style>
      </head>
      <body>
        <div class="container">
          <h1>Account Deleted</h1>
          <p>Your account associated with the phone number <strong>${phone}</strong> has been successfully deleted.</p>
        </div>
      </body>
      </html>
    `);
        }
        catch (error) {
            const err = error;
            // Render error HTML response
            res.status(500).send(`
      <!DOCTYPE html>
      <html lang="en">
      <head>
        <meta charset="UTF-8">
        <meta name="viewport" content="width=device-width, initial-scale=1.0">
        <title>Error Deleting Account</title>
        <style>
          body {
            font-family: Arial, sans-serif;
            background-color: #ffe6e6;
            margin: 0;
            padding: 0;
            display: flex;
            justify-content: center;
            align-items: center;
            height: 100vh;
          }
          .container {
            text-align: center;
            background-color: #fff;
            padding: 20px;
            border-radius: 10px;
            box-shadow: 0 4px 6px rgba(0, 0, 0, 0.1);
            max-width: 400px;
            width: 100%;
          }
          h1 {
            color: #dc3545;
            margin-bottom: 20px;
          }
          p {
            color: #333;
            font-size: 1rem;
          }
        </style>
      </head>
      <body>
        <div class="container">
          <h1>Error Deleting Account</h1>
          <p>${err.message}</p>
        </div>
      </body>
      </html>
    `);
        }
    }
    static async getAccount(req, res) {
        try {
            const accounts = await Account_1.default.get();
            res.json(accounts);
        }
        catch (error) {
            console.log(error);
            // @ts-ignore
            res.status(500).json({ error: error });
        }
    }
    static async renderDeletePage(req, res) {
        try {
            res.send(`
      <!DOCTYPE html>
      <html lang="en">
      <head>
        <meta charset="UTF-8">
        <meta name="viewport" content="width=device-width, initial-scale=1.0">
        <title>Deleting Your Data</title>
        <style>
          body {
            font-family: Arial, sans-serif;
            background-color: #f9f9f9;
            margin: 0;
            padding: 0;
            display: flex;
            justify-content: center;
            align-items: center;
            height: 100vh;
          }
          .container {
            background-color: #fff;
            padding: 20px;
            border-radius: 8px;
            box-shadow: 0 4px 6px rgba(0, 0, 0, 0.1);
            max-width: 400px;
            width: 100%;
            text-align: center;
          }
          h1 {
            margin-bottom: 1em;
            color: #333;
          }
          form {
            display: flex;
            flex-direction: column;
            gap: 1em;
          }
          input {
            padding: 10px;
            border: 1px solid #ccc;
            border-radius: 4px;
            font-size: 1em;
            width: 100%;
          }
          button {
            padding: 10px;
            background-color: #ff4c4c;
            color: white;
            border: none;
            border-radius: 4px;
            font-size: 1em;
            cursor: pointer;
          }
          button:hover {
            background-color: #e84343;
          }
        </style>
      </head>
      <body>
        <div class="container">
          <h1>Deleting Your Data</h1>
          <form action="/public/delete-data" method="POST" >
            <input type="text" name="phone" placeholder="Enter your phone number" required />
            <input type="password" name="password" placeholder="Enter your password" required />
            <button type="submit">Delete Data</button>
          </form>
        </div>
      </body>
      </html>
    `);
        }
        catch (error) {
            console.error(error);
            res.status(500).send(`
      <!DOCTYPE html>
      <html lang="en">
      <head>
        <meta charset="UTF-8">
        <meta name="viewport" content="width=device-width, initial-scale=1.0">
        <title>Error</title>
      </head>
      <body>
        <h1>Something went wrong</h1>
        <p>${error instanceof Error ? error.message : "Unknown error"}</p>
      </body>
      </html>
    `);
        }
    }
    static getRouter() {
        const router = (0, express_1.Router)();
        router.get("/page", this.getPages);
        router.get("/page/:name", this.getPage);
        router.get("/delete-data", this.renderDeletePage);
        router.get("/account", this.getAccount);
        router.post("/delete-data", this.deleteAccount);
        return router;
    }
}
exports.default = PublicController;
