"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const DataBase_1 = __importDefault(require("../DataBase"));
const Snowflake_1 = __importDefault(require("../Snowflake"));
const Tabels_1 = require("../Constants/Tabels");
const Utils_1 = require("../Constants/Utils");
class Analytic {
    constructor(id, user_id, date, total_sales, add_to_cart, customer_visits, active_users) {
        this.id = id;
        this.user_id = user_id;
        this.date = date;
        this.total_sales = total_sales;
        this.add_to_cart = add_to_cart;
        this.active_users = active_users;
        this.customer_visits = customer_visits;
    }
    static async getnu(column) {
        try {
            const today = await DataBase_1.default.sum(column, Tabels_1.ANALYTIC_TABLE, "WHERE DATE(date) = CURRENT_DATE;");
            const week = await DataBase_1.default.sum(column, Tabels_1.ANALYTIC_TABLE, "WHERE YEARWEEK(date, 1) = YEARWEEK(CURDATE(), 1);");
            const month = await DataBase_1.default.sum(column, Tabels_1.ANALYTIC_TABLE, "WHERE YEAR(date) = YEAR(CURDATE()) AND MONTH(date) = MONTH(CURDATE())");
            const all = await DataBase_1.default.sum(column, Tabels_1.ANALYTIC_TABLE);
            return { today, all, month, week };
        }
        catch (error) {
            throw error;
        }
    }
    static async getanalatics() {
        try {
            const total_sales = await this.getnu("total_sales");
            const add_to_cart = await this.getnu("add_to_cart");
            const active_users = await this.getnu("active_users");
            const visits = await this.getnu("customer_visits");
            return { visits, add_to_cart, total_sales, active_users };
        }
        catch (error) {
            throw error;
        }
    }
    static async addparchace(user_id, product_id) {
        try {
            await DataBase_1.default.create({ user_id, product_id }, "product_purchases");
        }
        catch (error) {
            throw error;
        }
    }
    static async addProductView(user_id, product_id) {
        try {
            await DataBase_1.default.create({ user_id, product_id }, "product_views");
        }
        catch (error) {
            throw error;
        }
    }
    static async addProductsearch(user_id, search_query) {
        try {
            await DataBase_1.default.create({ user_id, search_query }, "product_searches");
        }
        catch (error) {
            throw error;
        }
    }
    static async addnewsView(user_id, news_id) {
        try {
            await DataBase_1.default.create({ user_id, news_id }, "news_views");
        }
        catch (error) {
            throw error;
        }
    }
    static async addnewssearch(user_id, search_query) {
        try {
            await DataBase_1.default.create({ user_id, search_query }, "news_searches");
        }
        catch (error) {
            throw error;
        }
    }
    static async add(column) {
        try {
            const today = new Date().toISOString().split("T")[0]; // Use a consistent date format
            const count = await DataBase_1.default.count(Tabels_1.ANALYTIC_TABLE, `WHERE date = ? `, [today]);
            if (count > 0) {
                // Fetch the existing analytic record
                const analytic = await DataBase_1.default.get(`SELECT * FROM ${Tabels_1.ANALYTIC_TABLE} WHERE date = ? `, [today]);
                // Prepare the updated data
                const updatedModel = { [column]: (analytic[column] || 0) + 1 };
                await DataBase_1.default.update(analytic.id, updatedModel, Tabels_1.ANALYTIC_TABLE);
            }
            else {
                // Prepare the new data
                const id = Snowflake_1.default.nextId();
                // @ts-ignore
                const newModel = { id, date: today, [column]: 1 };
                // @ts-ignore
                await DataBase_1.default.create(newModel, Tabels_1.ANALYTIC_TABLE);
            }
        }
        catch (error) {
            console.error("Error in adding analytic data:", error); // Log the error with context
            throw error; // Optionally rethrow the error or handle it as needed
        }
    }
    static async get(page) {
        try {
            const Analytics = await DataBase_1.default.paginate(page, Utils_1.PAGE_SIZE, Tabels_1.ANALYTIC_TABLE);
            const count = await DataBase_1.default.count(Tabels_1.ANALYTIC_TABLE);
            return { Analytics, pages: Math.ceil(count / Utils_1.PAGE_SIZE) };
        }
        catch (error) {
            throw error;
        }
    }
}
exports.default = Analytic;
