"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const DataBase_1 = __importDefault(require("../DataBase"));
const Snowflake_1 = __importDefault(require("../Snowflake"));
const Tabels_1 = require("../Constants/Tabels");
class DailyUse {
    constructor(id, user_id, created_at, updated_at, product_id, day) {
        this.id = id;
        this.user_id = user_id;
        this.created_at = created_at;
        this.updated_at = updated_at;
        this.day = day;
        this.product_id = product_id;
    }
    static async create(user_id, product_id, day) {
        try {
            const id = Snowflake_1.default.nextId();
            await DataBase_1.default.create({ id: id.toString(), product_id, user_id, day }, Tabels_1.DAILYUSE_TABLE);
            return id;
        }
        catch (error) {
            throw error;
        }
    }
    static async getByDay(user_id, date) {
        try {
            const d = new Date(date);
            if (isNaN(d.getTime())) {
                throw new Error("Invalid date format");
            }
            const dailyuse = await DataBase_1.default.getAll(Tabels_1.DAILYUSE_TABLE, `
      ${Tabels_1.PRODUCT_TABLE}.*, 
      ${Tabels_1.CATEGORY_TABLE}.name as category_name, 
      ${Tabels_1.CATEGORY_TABLE}.photo as category_photo, 
      EXISTS (
        SELECT 1 FROM ${Tabels_1.DAILYUSE_RECORDS_TABLE} 
        WHERE ${Tabels_1.DAILYUSE_RECORDS_TABLE}.dailyuse_id = ${Tabels_1.DAILYUSE_TABLE}.id 
        AND ${Tabels_1.DAILYUSE_RECORDS_TABLE}.date = ?
      ) AS is_used
      `, `JOIN ${Tabels_1.PRODUCT_TABLE} ON ${Tabels_1.PRODUCT_TABLE}.id = ${Tabels_1.DAILYUSE_TABLE}.product_id 
       JOIN ${Tabels_1.CATEGORY_TABLE} ON ${Tabels_1.PRODUCT_TABLE}.Category_id = ${Tabels_1.CATEGORY_TABLE}.id`, `WHERE ${Tabels_1.DAILYUSE_TABLE}.user_id = ? AND ${Tabels_1.DAILYUSE_TABLE}.day = ?`, [d.toISOString().split("T")[0], user_id, d.getDay()] // Ensure the date format is correct
            );
            return dailyuse;
        }
        catch (error) {
            throw error;
        }
    }
    static async record(dailyuse_id) {
        try {
            const id = Snowflake_1.default.nextId();
            await DataBase_1.default.create({
                id: id.toString(),
                dailyuse_id,
                date: new Date().toISOString().split("T")[0], // Store as YYYY-MM-DD
            }, Tabels_1.DAILYUSE_RECORDS_TABLE // Fix table name
            );
            return id;
        }
        catch (error) {
            throw error;
        }
    }
    static async delete(id) {
        try {
            await DataBase_1.default.deleteById(id, Tabels_1.DAILYUSE_TABLE);
        }
        catch (error) {
            throw error;
        }
    }
}
exports.default = DailyUse;
