"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const DataBase_1 = __importDefault(require("../DataBase"));
const Snowflake_1 = __importDefault(require("../Snowflake"));
const Tabels_1 = require("../Constants/Tabels");
const Utils_1 = require("../Constants/Utils");
const Comments_1 = __importDefault(require("./Comments"));
class News {
    constructor(id, title, content, created_at, updated_at, News_image, topic_id) {
        this.title = title;
        this.content = content;
        this.id = id;
        this.created_at = created_at;
        this.updated_at = updated_at;
        this.topic_id = topic_id;
        this.News_image = News_image;
    }
    static async create(title, content, topic_id, News_image) {
        try {
            const id = Snowflake_1.default.nextId();
            const model = { title, id, content, topic_id };
            if (News_image)
                model.News_image = News_image;
            // @ts-ignore
            await DataBase_1.default.create(model, Tabels_1.NEWES_TABLE);
            return id;
        }
        catch (error) {
            throw error;
        }
    }
    static async update(id, title, content, topic_id, News_image) {
        try {
            const model = { title, content, topic_id };
            if (News_image)
                model.News_image = News_image;
            await DataBase_1.default.update(id, model, Tabels_1.NEWES_TABLE);
        }
        catch (error) {
            throw error;
        }
    }
    static async getbyidarray(ids) {
        try {
            const placeholders = ids.map(() => "?").join(", "); // Create placeholders for each ID
            const query = `WHERE id IN (${placeholders})`;
            const News = await DataBase_1.default.getAll(Tabels_1.NEWES_TABLE, `*`, ``, query, ids // Pass the array of IDs directly
            );
            return News;
        }
        catch (error) {
            throw error;
        }
    }
    static async getById(id) {
        try {
            const News = await DataBase_1.default.getById(id, Tabels_1.NEWES_TABLE, `${Tabels_1.NEWES_TABLE}.*`);
            const reviews = await Comments_1.default.getCommentsByNews(News.id);
            return { ...News, ...reviews };
        }
        catch (error) {
            throw error;
        }
    }
    static async searchNewss(keyword, page) {
        try {
            const offset = (page - 1) * Utils_1.PAGE_SIZE;
            const Newss = await DataBase_1.default.getAllRow(`SELECT p.*, ${this.getselect()}
FROM ${Tabels_1.NEWES_TABLE} p
${this.getjoin()}
WHERE p.title LIKE ? OR p.content LIKE ?
ORDER BY  p.created_at DESC
LIMIT ? OFFSET ?;`, ["%" + keyword + "%", "%" + keyword + "%", Utils_1.PAGE_SIZE, offset]);
            const count = await DataBase_1.default.count(Tabels_1.NEWES_TABLE, `WHERE ${Tabels_1.NEWES_TABLE}.title LIKE ? OR ${Tabels_1.NEWES_TABLE}.content LIKE ?`, [
                "%" + keyword + "%",
                "%" + keyword + "%",
            ]);
            return { Newss, pages: Math.ceil(count / Utils_1.PAGE_SIZE) };
        }
        catch (error) {
            throw error;
        }
    }
    static getjoin(p = "p") {
        return `LEFT JOIN ${Tabels_1.TOPIC_TABLE} ON ${p}.topic_id = ${Tabels_1.TOPIC_TABLE}.id`;
    }
    static getselect(p = "p") {
        return `${Tabels_1.TOPIC_TABLE}.name as topic_name, ${Tabels_1.TOPIC_TABLE}.photo as topic_photo`;
    }
    static async Topic(id, page) {
        try {
            const offset = (page - 1) * Utils_1.PAGE_SIZE;
            const Newss = await DataBase_1.default.getAllRow(`SELECT p.*, ${this.getselect()}
  FROM ${Tabels_1.NEWES_TABLE} p
  ${this.getjoin()}
  WHERE p.topic_id = ?
  ORDER BY p.created_at DESC
  LIMIT ? OFFSET ?;`, [id, Utils_1.PAGE_SIZE, offset]);
            const count = await DataBase_1.default.count(Tabels_1.NEWES_TABLE, `WHERE topic_id = ?`, [id]);
            return { Newss, pages: Math.ceil(count / Utils_1.PAGE_SIZE) };
        }
        catch (error) {
            throw error;
        }
    }
    static async getHomePersonalizedNews(user_id) {
        try {
            const news = await DataBase_1.default.getAllRow(`WITH recent_searches AS (
          SELECT p.topic_id, p.id AS news_id, COUNT(*) * 5 AS search_score
          FROM news_searches us
          JOIN ${Tabels_1.NEWES_TABLE} p ON us.search_query LIKE CONCAT('%', p.title, '%')
          WHERE us.user_id = ? AND us.searched_at >= DATE_SUB(NOW(), INTERVAL 7 DAY)
          GROUP BY p.topic_id, p.id
      ),
      recent_views AS (
          SELECT p.topic_id, p.id AS news_id, COUNT(*) * 1 AS view_score
          FROM news_views uv
          JOIN ${Tabels_1.NEWES_TABLE} p ON uv.news_id = p.id
          WHERE uv.user_id = ? AND uv.viewed_at >= DATE_SUB(NOW(), INTERVAL 30 DAY)
          GROUP BY p.topic_id, p.id
      ),
      combined_scores AS (
          SELECT topic_id, news_id, SUM(search_score) AS total_score FROM recent_searches GROUP BY topic_id, news_id
          UNION ALL
          SELECT topic_id, news_id, SUM(view_score) FROM recent_views GROUP BY topic_id, news_id
      ),
      topic_scores AS (
          SELECT news_id, topic_id, SUM(total_score) AS total_score
          FROM combined_scores
          GROUP BY news_id, topic_id
      )
      SELECT p.*, ${this.getselect()}, COALESCE(cs.total_score, 0) AS total_score
      FROM ${Tabels_1.NEWES_TABLE} p
      ${this.getjoin()}
      LEFT JOIN topic_scores cs ON p.id = cs.news_id
      ORDER BY cs.total_score DESC, p.created_at DESC
      LIMIT 10;`, [user_id, user_id]);
            return news;
        }
        catch (error) {
            throw error;
        }
    }
    static async getNewss(page) {
        try {
            const Newss = await DataBase_1.default.paginate(page, Utils_1.PAGE_SIZE, Tabels_1.NEWES_TABLE, `${Tabels_1.NEWES_TABLE}.*, ${Tabels_1.TOPIC_TABLE}.name as topic_name, ${Tabels_1.TOPIC_TABLE}.photo as topic_photo`, `JOIN ${Tabels_1.TOPIC_TABLE} ON ${Tabels_1.NEWES_TABLE}.topic_id = ${Tabels_1.TOPIC_TABLE}.id `);
            const count = await DataBase_1.default.count(Tabels_1.NEWES_TABLE);
            console.log(Newss);
            return { Newss, pages: Math.ceil(count / Utils_1.PAGE_SIZE) };
        }
        catch (error) {
            throw error;
        }
    }
    static async search(keyword) {
        try {
            return await DataBase_1.default.getAll(Tabels_1.NEWES_TABLE, "*", "", `WHERE title LIKE ? OR content LIKE ?`, ["%" + keyword + "%", "%" + keyword + "%"]);
        }
        catch (error) {
            throw error;
        }
    }
    static async delete(id) {
        try {
            await DataBase_1.default.deleteById(id, Tabels_1.NEWES_TABLE);
        }
        catch (error) {
            throw error;
        }
    }
}
exports.default = News;
