"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const DataBase_1 = __importDefault(require("../DataBase"));
const Snowflake_1 = __importDefault(require("../Snowflake"));
const Tabels_1 = require("../Constants/Tabels");
class Notifications {
    constructor(id, created_at, title, user_id, received_at, message, is_seen, is_received, is_deleted, is_edited, is_dirty) {
        this.id = id;
        this.created_at = created_at;
        this.title = title;
        this.user_id = user_id;
        this.received_at = received_at;
        this.message = message;
        this.is_seen = is_seen;
        this.is_received = is_received;
        this.is_deleted = is_deleted;
        this.is_edited = is_edited;
        this.is_dirty = is_dirty;
    }
    static async createNotification(data) {
        try {
            const id = Snowflake_1.default.nextId();
            await DataBase_1.default.create({
                ...data,
                id,
                is_seen: false,
                is_received: false,
                is_deleted: false,
                is_edited: false,
                is_dirty: false,
            }, Tabels_1.NOTIFICATIONS_TABLE);
            return id;
        }
        catch (error) {
            throw error;
        }
    }
    static async updateNotification(id, updates) {
        try {
            // @ts-ignore
            return await DataBase_1.default.update(id, { ...updates }, Tabels_1.NOTIFICATIONS_TABLE);
        }
        catch (error) {
            throw error;
        }
    }
    static async markAsReceived(notificationId) {
        return await this.updateNotification(notificationId, { is_received: true, received_at: new Date().toDateString() });
    }
    static async markAsReceivedBulk(notificationIds) {
        Promise.all(notificationIds.map(async (n) => {
            await this.updateNotification(n, { is_received: true, received_at: new Date().toDateString() });
        }));
    }
    // Mark a notification as seen
    static async markAsSeen(notificationId) {
        return await this.updateNotification(notificationId, { is_seen: true });
    }
    // Mark a notification as deleted
    static async markAsDeleted(notificationId) {
        return await this.updateNotification(notificationId, { is_deleted: true });
    }
    static async getNewNotifications(user_id) {
        try {
            const notifications = await DataBase_1.default.getAll(Tabels_1.NOTIFICATIONS_TABLE, "*", "", `WHERE is_received = false AND is_deleted = false AND user_id = ?`, [user_id]);
            return notifications;
        }
        catch (error) {
            throw error;
        }
    }
    static async read(id) {
        try {
            await DataBase_1.default.update(id, { is_read: 1 }, Tabels_1.NOTIFICATIONS_TABLE);
        }
        catch (error) {
            throw error;
        }
    }
}
exports.default = Notifications;
