"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.orderStatus = void 0;
const DataBase_1 = __importDefault(require("../DataBase"));
const Snowflake_1 = __importDefault(require("../Snowflake"));
const Tabels_1 = require("../Constants/Tabels");
const Utils_1 = require("../Constants/Utils");
const Analytic_1 = __importDefault(require("./Analytic"));
const OrderItem_1 = __importDefault(require("./OrderItem"));
var orderStatus;
(function (orderStatus) {
    orderStatus[orderStatus["new"] = 0] = "new";
    orderStatus[orderStatus["Paid"] = 1] = "Paid";
    orderStatus[orderStatus["canceled"] = 2] = "canceled";
    orderStatus[orderStatus["rejected"] = 3] = "rejected";
    orderStatus[orderStatus["completed"] = 4] = "completed";
})(orderStatus || (exports.orderStatus = orderStatus = {}));
class Order {
    constructor(id, Customer_id, created_at, updated_at, total, status, invoice, items) {
        this.id = id;
        this.Customer_id = Customer_id;
        this.created_at = created_at;
        this.updated_at = updated_at;
        this.total = total;
        this.invoice = invoice;
        this.status = status;
        this.items = items;
    }
    static async create(Customer_id, total, status, invoice) {
        try {
            const id = Snowflake_1.default.nextId();
            await Analytic_1.default.add("total_sales");
            await DataBase_1.default.create({ id, Customer_id, total, status, invoice }, Tabels_1.ORDERS_TABLE);
            return id;
        }
        catch (error) {
            throw error;
        }
    }
    static async getById(id) {
        try {
            const Order = await DataBase_1.default.getById(id, Tabels_1.ORDERS_TABLE);
            return Order;
        }
        catch (error) {
            throw error;
        }
    }
    static async uploadNewInvoice(id, invoice) {
        try {
            await DataBase_1.default.update(id, { invoice }, Tabels_1.ORDERS_TABLE);
        }
        catch (error) {
            throw error;
        }
    }
    static async updateStatus(id, status, reason) {
        try {
            await DataBase_1.default.update(id, reason ? { status, reason } : { status }, Tabels_1.ORDERS_TABLE);
        }
        catch (error) {
            throw error;
        }
    }
    static async get(page, status) {
        try {
            let where = "WHERE status = ? ";
            const params = [status];
            where += "ORDER BY created_at DESC";
            const Orders = await DataBase_1.default.paginate(page, Utils_1.PAGE_SIZE, Tabels_1.ORDERS_TABLE, "*", "", where, params);
            const result = await Promise.all(Orders.map(async (o) => {
                const items = await OrderItem_1.default.getItemsByOrderId(o.id);
                return { ...o, items };
            }));
            const count = await DataBase_1.default.count(Tabels_1.ORDERS_TABLE, "WHERE status = ?", [status]);
            return { Orders: result, pages: Math.ceil(count / Utils_1.PAGE_SIZE) };
        }
        catch (error) {
            throw error;
        }
    }
    static async getOrdersForCustomer(Customer_id, page, status) {
        try {
            let where = "WHERE Customer_id = ? ";
            const params = [Customer_id];
            if (status || status === 0) {
                where += "AND status = ? ";
                params.push(status);
            }
            where += "ORDER BY created_at DESC";
            const Orders = await DataBase_1.default.paginate(page, Utils_1.PAGE_SIZE, Tabels_1.ORDERS_TABLE, "*", "", where, params);
            const result = await Promise.all(Orders.map(async (o) => {
                const items = await OrderItem_1.default.getItemsByOrderId(o.id);
                return { ...o, items };
            }));
            const count = await DataBase_1.default.count(Tabels_1.ORDERS_TABLE, "WHERE Customer_id = ?", [Customer_id]);
            return { Orders: result, pages: Math.ceil(count / Utils_1.PAGE_SIZE) };
        }
        catch (error) {
            throw error;
        }
    }
    static async delete(id) {
        try {
            await DataBase_1.default.deleteById(id, Tabels_1.ORDERS_TABLE);
        }
        catch (error) {
            throw error;
        }
    }
}
exports.default = Order;
