"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const DataBase_1 = __importDefault(require("../DataBase"));
const Snowflake_1 = __importDefault(require("../Snowflake"));
const Tabels_1 = require("../Constants/Tabels");
const Utils_1 = require("../Constants/Utils");
const Reviews_1 = __importDefault(require("./Reviews"));
class Product {
    constructor(id, Category_id, name, description, usage, created_at, updated_at, product_image, price, recomended_usage, inventory_count, category_photo, category_name, is_in_wishlist, is_in_cart) {
        this.name = name;
        this.description = description;
        this.usage_describtion = usage;
        this.id = id;
        this.Category_id = Category_id;
        this.created_at = created_at;
        this.updated_at = updated_at;
        this.product_image = product_image;
        this.price = price;
        this.recomended_usage = recomended_usage;
        this.category_name = category_name;
        this.category_photo = category_photo;
        this.is_in_wishlist = is_in_wishlist;
        this.is_in_cart = is_in_cart;
    }
    static async create(name, Category_id, description, usage_describtion, price, recomended_usage, product_image) {
        try {
            const id = Snowflake_1.default.nextId();
            const model = { name, id, description, usage_describtion, Category_id, price, recomended_usage };
            if (product_image)
                model.product_image = product_image;
            // @ts-ignore
            await DataBase_1.default.create(model, Tabels_1.PRODUCT_TABLE);
            return id;
        }
        catch (error) {
            throw error;
        }
    }
    static async update(id, name, Category_id, description, usage_describtion, price, recomended_usage, product_image) {
        try {
            const model = { name, description, usage_describtion, Category_id, price, recomended_usage };
            if (product_image)
                model.product_image = product_image;
            await DataBase_1.default.update(id, model, Tabels_1.PRODUCT_TABLE);
        }
        catch (error) {
            throw error;
        }
    }
    static async getbyidarray(ids) {
        try {
            const placeholders = ids.map(() => "?").join(", "); // Create placeholders for each ID
            const query = `WHERE id IN (${placeholders})`;
            const Product = await DataBase_1.default.getAll(Tabels_1.PRODUCT_TABLE, `*`, ``, query, ids // Pass the array of IDs directly
            );
            return Product;
        }
        catch (error) {
            throw error;
        }
    }
    static async getById(id) {
        try {
            const Product = await DataBase_1.default.getById(id, Tabels_1.PRODUCT_TABLE, `${Tabels_1.PRODUCT_TABLE}.*, ${this.getselect(Tabels_1.PRODUCT_TABLE)}`, this.getjoin(Tabels_1.PRODUCT_TABLE));
            const reviews = await Reviews_1.default.getReviewsByProduct(Product.id);
            return { ...Product, ...reviews };
        }
        catch (error) {
            throw error;
        }
    }
    static async searchproducts(keyword, page) {
        try {
            const offset = (page - 1) * Utils_1.PAGE_SIZE;
            const Products = await DataBase_1.default.getAllRow(`SELECT p.*, ${this.getselect()}
FROM ${Tabels_1.PRODUCT_TABLE} p
${this.getjoin()}
WHERE p.name LIKE ? OR p.description LIKE ?
ORDER BY  p.created_at DESC
LIMIT ? OFFSET ?;`, ["%" + keyword + "%", "%" + keyword + "%", Utils_1.PAGE_SIZE, offset]);
            const count = await DataBase_1.default.count(Tabels_1.PRODUCT_TABLE, `${this.getjoin(Tabels_1.PRODUCT_TABLE)} WHERE ${Tabels_1.PRODUCT_TABLE}.name LIKE ? OR ${Tabels_1.PRODUCT_TABLE}.description LIKE ?`, ["%" + keyword + "%", "%" + keyword + "%"]);
            return { Products, pages: Math.ceil(count / Utils_1.PAGE_SIZE) };
        }
        catch (error) {
            throw error;
        }
    }
    static getjoin(p = "p") {
        return `LEFT JOIN ${Tabels_1.CATEGORY_TABLE} ON ${p}.Category_id = ${Tabels_1.CATEGORY_TABLE}.id`;
    }
    static getselect(p = "p") {
        return `${Tabels_1.CATEGORY_TABLE}.name as category_name, ${Tabels_1.CATEGORY_TABLE}.photo as category_photo, 
        IF((SELECT count(*) FROM ${Tabels_1.WISHLIST_TABLE} WHERE product_id = ${p}.id) > 0, true, false) AS is_in_wishlist,
        IF((SELECT count(*) FROM ${Tabels_1.CART_TABLE} WHERE product_id = ${p}.id) > 0, true, false) AS is_in_cart`;
    }
    static async getByCategory(id, page) {
        try {
            const offset = (page - 1) * Utils_1.PAGE_SIZE;
            const Products = await DataBase_1.default.getAllRow(`SELECT p.*, ${this.getselect()}
FROM ${Tabels_1.PRODUCT_TABLE} p
${this.getjoin()}
WHERE p.Category_id = ?
ORDER BY p.created_at DESC
LIMIT ? OFFSET ?;`, [id, Utils_1.PAGE_SIZE, offset]);
            const count = await DataBase_1.default.count(Tabels_1.PRODUCT_TABLE, `WHERE Category_id = ?`, [id]);
            return { Products, pages: Math.ceil(count / Utils_1.PAGE_SIZE) };
        }
        catch (error) {
            throw error;
        }
    }
    static async getHomePersonlizedProducts(user_id) {
        try {
            const Products = await DataBase_1.default.getAllRow(`WITH recent_searches AS (
    SELECT p.Category_id, p.id AS product_id, COUNT(*) * 5 AS search_score
    FROM product_searches us
    JOIN ${Tabels_1.PRODUCT_TABLE} p ON us.search_query LIKE CONCAT('%', p.name, '%')
    WHERE us.user_id = ? AND us.searched_at >= DATE_SUB(NOW(), INTERVAL 7 DAY)
    GROUP BY p.Category_id, p.id
),
recent_purchases AS (
    SELECT p.Category_id, p.id AS product_id, COUNT(*) * 3 AS purchase_score
    FROM product_purchases up
    JOIN ${Tabels_1.PRODUCT_TABLE} p ON up.product_id = p.id
    WHERE up.user_id = ? AND up.purchased_at >= DATE_SUB(NOW(), INTERVAL 30 DAY)
    GROUP BY p.Category_id, p.id
),
recent_views AS (
    SELECT p.Category_id, p.id AS product_id, COUNT(*) * 1 AS view_score
    FROM product_views uv
    JOIN ${Tabels_1.PRODUCT_TABLE} p ON uv.product_id = p.id
    WHERE uv.user_id = ? AND uv.viewed_at >= DATE_SUB(NOW(), INTERVAL 30 DAY)
    GROUP BY p.Category_id, p.id
),
category_scores AS (
    SELECT
        COALESCE(rs.Category_id, rp.Category_id, rv.Category_id) AS Category_id,
        COALESCE(rs.product_id, rp.product_id, rv.product_id) AS product_id,
        SUM(COALESCE(rs.search_score, 0) + COALESCE(rp.purchase_score, 0) + COALESCE(rv.view_score, 0)) AS total_score
    FROM recent_searches rs
    RIGHT JOIN recent_purchases rp ON rs.product_id = rp.product_id
    RIGHT JOIN recent_views rv ON COALESCE(rs.product_id, rp.product_id) = rv.product_id
    GROUP BY COALESCE(rs.Category_id, rp.Category_id, rv.Category_id), COALESCE(rs.product_id, rp.product_id, rv.product_id)
)
SELECT p.*, cs.total_score, ${this.getselect()}
FROM ${Tabels_1.PRODUCT_TABLE} p
LEFT JOIN category_scores cs ON p.id = cs.product_id
${this.getjoin()}
WHERE p.Category_id IN (SELECT Category_id FROM category_scores ORDER BY total_score DESC)
OR cs.total_score IS NULL
ORDER BY COALESCE(cs.total_score, 0) DESC, p.created_at DESC
LIMIT 10;
`, [user_id, user_id, user_id]);
            return Products;
        }
        catch (error) {
            throw error;
        }
    }
    static async getProducts(page) {
        try {
            const Products = await DataBase_1.default.paginate(page, Utils_1.PAGE_SIZE, Tabels_1.PRODUCT_TABLE, `${Tabels_1.PRODUCT_TABLE}.*, ${Tabels_1.CATEGORY_TABLE}.name as category_name, ${Tabels_1.CATEGORY_TABLE}.photo as category_photo`, `JOIN ${Tabels_1.CATEGORY_TABLE} ON ${Tabels_1.PRODUCT_TABLE}.Category_id = ${Tabels_1.CATEGORY_TABLE}.id `);
            const count = await DataBase_1.default.count(Tabels_1.PRODUCT_TABLE);
            console.log(Products);
            return { Products, pages: Math.ceil(count / Utils_1.PAGE_SIZE) };
        }
        catch (error) {
            throw error;
        }
    }
    static async search(keyword) {
        try {
            return await DataBase_1.default.getAll(Tabels_1.PRODUCT_TABLE, "*", "", `name LIKE ? OR description LIKE ?`, ["%" + keyword + "%", "%" + keyword + "%"]);
        }
        catch (error) {
            throw error;
        }
    }
    static async delete(id) {
        try {
            await DataBase_1.default.deleteById(id, Tabels_1.PRODUCT_TABLE);
        }
        catch (error) {
            throw error;
        }
    }
}
exports.default = Product;
