"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const DataBase_1 = __importDefault(require("../DataBase"));
const Snowflake_1 = __importDefault(require("../Snowflake"));
const Tabels_1 = require("../Constants/Tabels");
const Utils_1 = require("../Constants/Utils");
class Reviews {
    constructor(id, user_id, created_at, updated_at, product_id, review_text, rating) {
        this.id = id;
        this.user_id = user_id;
        this.created_at = created_at;
        this.updated_at = updated_at;
        this.product_id = product_id;
        this.review_text = review_text;
        this.rating = rating;
    }
    static async create(user_id, product_id, rating, review_text) {
        try {
            const id = Snowflake_1.default.nextId();
            const reviews = await DataBase_1.default.getAll(Tabels_1.REVIEWS_TABLE, "*", "", "WHERE user_id = ? AND product_id = ?", [user_id, product_id]);
            if (reviews.length > 0)
                await DataBase_1.default.update(reviews[0].id, { rating, review_text }, Tabels_1.REVIEWS_TABLE);
            else
                await DataBase_1.default.create({ id, product_id, review_text, user_id, rating }, Tabels_1.REVIEWS_TABLE);
            await DataBase_1.default.create({ id, product_id, review_text, user_id, rating }, Tabels_1.REVIEWS_TABLE);
            return id;
        }
        catch (error) {
            throw error;
        }
    }
    static async getById(id) {
        try {
            const Order = await DataBase_1.default.getById(id, Tabels_1.REVIEWS_TABLE);
            return Order;
        }
        catch (error) {
            throw error;
        }
    }
    static async getReviewsByProduct(product_id) {
        try {
            const Reviews = await DataBase_1.default.getAll(Tabels_1.REVIEWS_TABLE, `${Tabels_1.REVIEWS_TABLE}.*, ${Tabels_1.USER_TABLE}.name as user_name`, `LEFT JOIN ${Tabels_1.USER_TABLE} ON ${Tabels_1.REVIEWS_TABLE}.user_id = ${Tabels_1.USER_TABLE}.id`, "WHERE product_id = ? LIMIT 3", [product_id]);
            const count = await DataBase_1.default.count(Tabels_1.REVIEWS_TABLE, "WHERE product_id = ?", [product_id]);
            const rate = await DataBase_1.default.AVG("rating", Tabels_1.REVIEWS_TABLE, "WHERE product_id = ?", [product_id]);
            return { Reviews, reviews_count: count, rate };
        }
        catch (error) {
            throw error;
        }
    }
    static async getAllReviewsByProduct(product_id, page) {
        try {
            const Reviews = await DataBase_1.default.paginate(page, Utils_1.PAGE_SIZE, Tabels_1.REVIEWS_TABLE, `${Tabels_1.REVIEWS_TABLE}.*, ${Tabels_1.USER_TABLE}.name as user_name`, `LEFT JOIN ${Tabels_1.USER_TABLE} ON ${Tabels_1.REVIEWS_TABLE}.user_id = ${Tabels_1.USER_TABLE}.id`, "WHERE product_id = ?", [product_id]);
            const count = await DataBase_1.default.count(Tabels_1.REVIEWS_TABLE, "WHERE product_id = ?", [product_id]);
            return { Reviews, pages: Math.ceil(count / Utils_1.PAGE_SIZE) };
        }
        catch (error) {
            throw error;
        }
    }
    static async delete(id) {
        try {
            await DataBase_1.default.deleteById(id, Tabels_1.REVIEWS_TABLE);
        }
        catch (error) {
            throw error;
        }
    }
}
exports.default = Reviews;
