"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.userstatus = exports.userType = void 0;
const DataBase_1 = __importDefault(require("../DataBase"));
const uuid_1 = require("uuid");
const Snowflake_1 = __importDefault(require("../Snowflake"));
const Tabels_1 = require("../Constants/Tabels");
const Utils_1 = require("../Constants/Utils");
var userType;
(function (userType) {
    userType[userType["admin"] = 0] = "admin";
    userType[userType["user"] = 1] = "user";
})(userType || (exports.userType = userType = {}));
var userstatus;
(function (userstatus) {
    userstatus[userstatus["active"] = 0] = "active";
    userstatus[userstatus["blocked"] = 1] = "blocked";
})(userstatus || (exports.userstatus = userstatus = {}));
class User {
    constructor(id, name, password, created_at, updated_at, type, status, last_seen, phone, profile_pic) {
        this.phone = phone;
        this.name = name;
        this.password = password;
        this.id = id;
        this.type = type;
        this.status = status;
        this.profile_pic = profile_pic;
        this.created_at = created_at;
        this.updated_at = updated_at;
        this.last_seen = last_seen;
    }
    static async create(name, phone, password, type, photo) {
        try {
            const count = await DataBase_1.default.count(Tabels_1.USER_TABLE, "WHERE phone = ?", [phone]);
            if (count > 0)
                throw new Error("phone already used");
            const id = Snowflake_1.default.nextId();
            let model = { name, id, password, phone, type, status: userstatus.active };
            if (photo)
                model.profile_pic = photo;
            await DataBase_1.default.create(model, Tabels_1.USER_TABLE);
            return id;
        }
        catch (error) {
            throw error;
        }
    }
    static async updateInfo(id, name, phone, profile_pic) {
        try {
            let model = { name, phone };
            if (profile_pic)
                model.profile_pic = profile_pic;
            await DataBase_1.default.update(id, model, Tabels_1.USER_TABLE);
        }
        catch (error) {
            throw error;
        }
    }
    static async updateLastseen(id) {
        try {
            await DataBase_1.default.update(id, { last_seen: new Date().toISOString().split("T")[0] }, Tabels_1.USER_TABLE);
        }
        catch (error) {
            throw error;
        }
    }
    static async updateStatus(id, status) {
        try {
            await DataBase_1.default.update(id, { status }, Tabels_1.USER_TABLE);
        }
        catch (error) {
            throw error;
        }
    }
    static async updateType(id, type = userType.user) {
        try {
            await DataBase_1.default.update(id, { type }, Tabels_1.USER_TABLE);
        }
        catch (error) {
            throw error;
        }
    }
    static async updateAdmin(id, password, name, phone, photo) {
        try {
            const otherusers = await this.getByphone(phone);
            if (otherusers.length > 1)
                throw "phone is used";
            if (otherusers.length === 1 && otherusers[0].id !== id)
                throw "phone is used";
            let model = { name, password, phone };
            if (photo)
                model.profile_pic = photo;
            await DataBase_1.default.update(id, model, Tabels_1.USER_TABLE);
        }
        catch (error) {
            throw error;
        }
    }
    static async getByphone(phone) {
        try {
            const user = await DataBase_1.default.getAll(Tabels_1.USER_TABLE, "*", "", "WHERE phone = ?", [phone]);
            return user;
        }
        catch (error) {
            throw error;
        }
    }
    static async search(keyword, page) {
        try {
            const users = await DataBase_1.default.paginate(page, Utils_1.PAGE_SIZE, Tabels_1.USER_TABLE, `*`, ``, `WHERE name LIKE ? `, ["%" + keyword + "%"]);
            const count = await DataBase_1.default.count(Tabels_1.USER_TABLE, ` WHERE name LIKE ? `, ["%" + keyword + "%"]);
            return { users, pages: Math.ceil(count / Utils_1.PAGE_SIZE) };
        }
        catch (error) {
            throw error;
        }
    }
    static async getanalatics() {
        try {
            const today = await DataBase_1.default.count(Tabels_1.USER_TABLE, "WHERE DATE(created_at) = CURRENT_DATE;");
            const week = await DataBase_1.default.count(Tabels_1.USER_TABLE, "WHERE YEARWEEK(created_at, 1) = YEARWEEK(CURDATE(), 1);");
            const month = await DataBase_1.default.count(Tabels_1.USER_TABLE, "WHERE YEAR(created_at) = YEAR(CURDATE()) AND MONTH(created_at) = MONTH(CURDATE())");
            const all = await DataBase_1.default.count(Tabels_1.USER_TABLE);
            return { today, all, month, week };
        }
        catch (error) {
            throw error;
        }
    }
    static async getByToken(authHeader) {
        try {
            if (!authHeader)
                throw new Error("no token");
            const token = authHeader.split(" ")[1]; // get the token
            const rows = await DataBase_1.default.getAll("tokens t", "u.* ", `JOIN ${Tabels_1.USER_TABLE} u ON u.id = t.user_id`, "WHERE t.token = ?", [token]);
            const row = rows[0];
            if (row)
                return row;
            throw new Error("not found");
        }
        catch (error) {
            throw error;
        }
    }
    static async getById(id) {
        try {
            const user = await DataBase_1.default.getById(id, Tabels_1.USER_TABLE);
            return user;
        }
        catch (error) {
            throw error;
        }
    }
    static async getusers(page, type) {
        try {
            const users = await DataBase_1.default.paginate(page, Utils_1.PAGE_SIZE, Tabels_1.USER_TABLE, "*", "", "WHERE type = ?", [type]);
            const count = await DataBase_1.default.count(Tabels_1.USER_TABLE);
            return { users, pages: Math.ceil(count / Utils_1.PAGE_SIZE) };
        }
        catch (error) {
            throw error;
        }
    }
    static async delete(id) {
        try {
            await DataBase_1.default.deleteById(id, Tabels_1.USER_TABLE);
        }
        catch (error) {
            throw error;
        }
    }
    static async login(phone, password, type) {
        try {
            const rows = await DataBase_1.default.getAll(Tabels_1.USER_TABLE, "*", "", "WHERE phone = ?", [phone]);
            const row = rows[0];
            if (!row)
                throw new Error("phone not found");
            if (type && row.type !== type)
                throw new Error("you are not authrize to use this service");
            // const isPasswordValid = await bcrypt.compare(password, row.password);
            const isPasswordValid = password === row.password;
            if (isPasswordValid) {
                // Password is correct, generate a token
                const token = (0, uuid_1.v4)();
                // Store the token in the tokens table
                await DataBase_1.default.create({ user_id: row.id, token }, "tokens");
                return { token, user: row };
            }
            else {
                throw new Error("Incorrect password");
            }
        }
        catch (error) {
            console.log(error);
            throw error;
        }
    }
    static async logout(tokenId) {
        try {
            await DataBase_1.default.deleteByColumn(tokenId, "tokens", "token");
            return Promise.resolve();
        }
        catch (err) {
            throw err;
        }
    }
    static async changePassword(userId, oldPassword, newPassword) {
        try {
            // Retrieve the user from the database
            const row = await DataBase_1.default.getById(userId, Tabels_1.USER_TABLE);
            if (!row)
                throw new Error("User not found");
            // const isOldPasswordValid = await bcrypt.compare(oldPassword , row.password);
            const isOldPasswordValid = oldPassword === row.password;
            console.log(oldPassword, newPassword, row.password);
            if (isOldPasswordValid) {
                // Old password is correct, hash the new password
                // const hashedNewPassword = await bcrypt.hash(newPassword, 10); // You can adjust the saltRounds as needed
                const hashedNewPassword = newPassword; // You can adjust the saltRounds as needed
                // Update the user's password in the database
                await DataBase_1.default.update(row.id, { password: hashedNewPassword }, Tabels_1.USER_TABLE);
                return Promise.resolve();
            }
            else {
                throw new Error("Old password is incorrect"); // Old password is incorrect
            }
        }
        catch (error) {
            throw error;
        }
    }
}
exports.default = User;
